adapt3-package: Adaptive Dynamics and Community Matrix Model Projections

adapt3-packageR Documentation

Adaptive Dynamics and Community Matrix Model Projections

Description

Runs projections of groups of matrix projection models (MPMs), allowing density dependence mechanisms to work across MPMs. This package was developed to run both adaptive dynamics simulations such as pairwise and multiple invasion analysis, and community projections in which species are represented by MPMs. All forms of MPMs are allowed, including integral projection models (IPMs).

Details

The adapt3 package provides three categories of functions:

1. Core projection

2. Function characterizing relationships among MPMs

3. Functions describing, summarizing, or visualizing results

adapt3 also includes example datasets complete with sample code.

Author(s)

Maintainer: Richard P. Shefferson cdorm@g.ecc.u-tokyo.ac.jp (ORCID)

Authors:

Richard P. Shefferson <cdorm@g.ecc.u-tokyo.ac.jp>

References

Shefferson, R.P. 2026. adapt3: adaptive dynamics and community projection in the R programming language. Methods in Ecology and Evolution 17(6): 1719-1725.

See Also

Useful links:


adapt3 documentation built on June 7, 2026, 9:08 a.m.