| adapt3-package | R Documentation |
Runs projections of groups of matrix projection models (MPMs), allowing density dependence mechanisms to work across MPMs. This package was developed to run both adaptive dynamics simulations such as pairwise and multiple invasion analysis, and community projections in which species are represented by MPMs. All forms of MPMs are allowed, including integral projection models (IPMs).
The adapt3 package provides three categories of functions:
1. Core projection
2. Function characterizing relationships among MPMs
3. Functions describing, summarizing, or visualizing results
adapt3 also includes example datasets complete with sample code.
Maintainer: Richard P. Shefferson cdorm@g.ecc.u-tokyo.ac.jp (ORCID)
Authors:
Richard P. Shefferson cdorm@g.ecc.u-tokyo.ac.jp (ORCID)
Richard P. Shefferson <cdorm@g.ecc.u-tokyo.ac.jp>
Shefferson, R.P. 2026. adapt3: adaptive dynamics and community projection in the R programming language. Methods in Ecology and Evolution 17(6): 1719-1725.
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.